==> agr-center-api-3.0.0-CLOUD-UAT-20220826.025917-5-sources.jar: com/tydic/dyc/agr/service/agr/bo/AgrMainSaveBo.java <==
package com.tydic.dyc.agr.service.agr.bo;

import lombok.Data;
import java.io.Serializable;
import com.tydic.dyc.agr.service.agr.bo.AgrPayConfigBo;
import com.tydic.dyc.agr.service.agr.bo.AgrPayConfigBo;
import com.tydic.dyc.agr.service.agr.bo.AgrMainExtBo;
import java.util.Date;
import java.math.BigDecimal;
import java.util.List;

/**
 * 描述：null 
 * 
 * @author auto_gen
 * @date 2022-08-25 13:33
 **/
@Data
public class AgrMainSaveBo implements Serializable {
	private static final long serialVersionUID =  5801690114505766709L;

	/**
	 * 协议ID
	 */
	private Long agrId;
	/**
	 * 协议来源
	 */
	private Integer agrSrc;
	/**
	 * 协议来源编码
	 */
	private String agrSrcCode;
	/**
	 * 协议来源名称
	 */
	private String agrSrcName;
	/**
	 * 协议编号
	 */
	private String agrCode;
	/**
	 * 企业协议编号
	 */
	private String enAgrCode;
	/**
	 * 协议名称
	 */
	private String agrName;
	/**
	 * 协议模式
	 */
	private Integer agrMode;
	/**
	 * 交易模式
	 */
	private Integer tradeMode;
	/**
	 * 标的物名称
	 */
	private String matterName;
	/**
	 * 采购类别
	 */
	private Integer agreementVariety;
	/**
	 * 组织名称
	 */
	private String agrOrgName;
	/**
	 * 铺货方式
	 */
	private Integer supplierMode;
	/**
	 * 铺货单位ID
	 */
	private Long managementOrgId;
	/**
	 * 铺货单位名称
	 */
	private String managementOrgName;
	/**
	 * 供货商ID
	 */
	private Long supplierId;
	/**
	 * 供货商名称
	 */
	private String supplierName;
	/**
	 * 供货商联系人
	 */
	private String supplierContact;
	/**
	 * 供货商联系电话
	 */
	private String supplierPhone;
	/**
	 * 协议生效日期
	 */
	private Date effDate;
	/**
	 * 协议失效日期
	 */
	private Date expDate;
	/**
	 * 付款方式（对供应商）贸易模式必填
	 */
	private AgrPayConfigBo payTypeSup;
	/**
	 * 付款方式（对采购商）贸易模式必填
	 */
	private AgrPayConfigBo payTypePur;
	/**
	 * 其他付款条件
	 */
	private String payCase;
	/**
	 * 质保期时间
	 */
	private String quaprotectCount;
	/**
	 * 质保期单位
	 */
	private String quaprotectUnit;
	/**
	 * 协议签订时间
	 */
	private Date agrSignTime;
	/**
	 * 协议编制时间
	 */
	private Date createTime;
	/**
	 * 应用范围类型
	 */
	private Integer scopeType;
	/**
	 * 调价机制0：无，1：事前调价，2事中调价 
	 */
	private Integer adjustPrice;
	/**
	 * 是否存在加价项
	 */
	private BigDecimal isAddPrice;
	/**
	 * 加价比率（%）
	 */
	private Integer markupRate;
	/**
	 * 是否公式调价
	 */
	private Integer isAdjustPriceFormula;
	/**
	 * 是否手动修改采购单价
	 */
	private Long isModifyBuyPrice;
	/**
	 * 调价公式ID
	 */
	private String adjustPriceFormulaId;
	/**
	 * 调价公式名称
	 */
	private String adjustPriceFormulaName;
	/**
	 * 调价公式值
	 */
	private String adjustPriceFormulaValue;
	/**
	 * 调价公式说明
	 */
	private Long adjustPriceFormula;
	/**
	 * 备注
	 */
	private String remark;
	/**
	 * 协议类别id
	 */
	private Long agrCategoryId;
	/**
	 * 协议类别名称
	 */
	private String agrCategoryName;
	/**
	 * 协议分类
	 */
	private Integer agrType;
	/**
	 * 协议价格类型
	 */
	private Integer agrPriceType;
	/**
	 * 是否配送
	 */
	private Integer isDispatch;
	/**
	 * 是否分配
	 */
	private Integer isAssign;
	/**
	 * 供货周期
	 */
	private Integer supplyCycle;
	/**
	 * 所属专区
	 */
	private Integer agrLocation;
	/**
	 * 是否商城铺货标识
	 */
	private Long isStorePlan;
	/**
	 * 协议主体拓展
	 */
	private List<AgrMainExtBo> agrMainExtBOs;
	/**
	 * 操作流水号
	 */
	private String operNo;
	/**
	 * 经办人ID
	 */
	private Long agrOperatorId;
	/**
	 * 经办人名称
	 */
	private String agrOperatorName;
	/**
	 * 经办人用户名
	 */
	private String agrOperatorUsername;
	/**
	 * 排序
	 */
	private String orderBy;

}

==> agr-center-api-3.1.1-CLOUD-UAT-20231206.014930-14-sources.jar: com/tydic/dyc/agr/service/agr/bo/AgrMainSaveBo.java <==
package com.tydic.dyc.agr.service.agr.bo;

import lombok.Data;
import java.io.Serializable;
import com.tydic.dyc.agr.service.agr.bo.AgrPayConfigBo;
import com.tydic.dyc.agr.service.agr.bo.AgrPayConfigBo;
import com.tydic.dyc.agr.service.agr.bo.AgrMainExtBo;
import java.util.Date;
import java.math.BigDecimal;
import java.util.List;

/**
 * 描述：null 
 * 
 * @author auto_gen
 * @date 2023-02-08 12:03
 **/
@Data
public class AgrMainSaveBo implements Serializable {
	private static final long serialVersionUID =  -6530517208003219605L;

	/**
	 * 协议来源
	 */
	private Integer agrSrc;
	/**
	 * 协议来源编码
	 */
	private String agrSrcCode;
	/**
	 * 协议来源名称
	 */
	private String agrSrcName;
	/**
	 * 协议编号
	 */
	private String agrCode;
	/**
	 * 企业协议编号
	 */
	private String enAgrCode;
	/**
	 * 协议名称
	 */
	private String agrName;
	/**
	 * 协议模式
	 */
	private Integer agrMode;
	/**
	 * 交易模式
	 */
	private Integer tradeMode;
	/**
	 * 标的物名称
	 */
	private String matterName;
	/**
	 * 采购类别
	 */
	private Integer agreementVariety;
	/**
	 * 组织名称
	 */
	private String agrOrgName;
	/**
	 * 铺货方式
	 */
	private Integer supplierMode;
	/**
	 * 铺货单位ID
	 */
	private Long managementOrgId;
	/**
	 * 铺货单位名称
	 */
	private String managementOrgName;
	/**
	 * 供货商ID
	 */
	private Long supplierId;
	/**
	 * 供货商名称
	 */
	private String supplierName;
	/**
	 * 供货商联系人
	 */
	private String supplierContact;
	/**
	 * 供货商联系电话
	 */
	private String supplierPhone;
	/**
	 * 协议生效日期
	 */
	private Date effDate;
	/**
	 * 协议失效日期
	 */
	private Date expDate;
	/**
	 * 付款方式（对供应商）贸易模式必填
	 */
	private AgrPayConfigBo payTypeSup;
	/**
	 * 付款方式（对采购商）贸易模式必填
	 */
	private AgrPayConfigBo payTypePur;
	/**
	 * 其他付款条件
	 */
	private String payCase;
	/**
	 * 质保期时间
	 */
	private String quaprotectCount;
	/**
	 * 质保期单位
	 */
	private String quaprotectUnit;
	/**
	 * 协议签订时间
	 */
	private Date agrSignTime;
	/**
	 * 协议编制时间
	 */
	private Date createTime;
	/**
	 * 应用范围类型
	 */
	private Integer scopeType;
	/**
	 * 调价机制0：无，1：事前调价，2事中调价 
	 */
	private Integer adjustPrice;
	/**
	 * 是否存在加价项
	 */
	private BigDecimal isAddPrice;
	/**
	 * 加价比率（%）
	 */
	private BigDecimal markupRate;
	/**
	 * 是否公式调价
	 */
	private Integer isAdjustPriceFormula;
	/**
	 * 是否手动修改采购单价
	 */
	private Long isModifyBuyPrice;
	/**
	 * 调价公式ID
	 */
	private String adjustPriceFormulaId;
	/**
	 * 调价公式名称
	 */
	private String adjustPriceFormulaName;
	/**
	 * 调价公式值
	 */
	private String adjustPriceFormulaValue;
	/**
	 * 调价公式说明
	 */
	private Long adjustPriceFormula;
	/**
	 * 备注
	 */
	private String remark;
	/**
	 * 协议类别id
	 */
	private Long agrCategoryId;
	/**
	 * 协议类别名称
	 */
	private String agrCategoryName;
	/**
	 * 协议分类
	 */
	private Integer agrType;
	/**
	 * 协议价格类型
	 */
	private Integer agrPriceType;
	/**
	 * 是否配送
	 */
	private Integer isDispatch;
	/**
	 * 是否分配
	 */
	private Integer isAssign;
	/**
	 * 供货周期
	 */
	private Integer supplyCycle;
	/**
	 * 所属专区
	 */
	private Integer agrLocation;
	/**
	 * 是否商城铺货标识
	 */
	private Integer whetherStorePlan;
	/**
	 * 是否有明细标识
	 */
	private Integer whetherHaveItem;
	/**
	 * 协议主体拓展
	 */
	private List<AgrMainExtBo> agrMainExtBOs;
	/**
	 * 经办人ID
	 */
	private Long agrOperatorId;
	/**
	 * 经办人名称
	 */
	private String agrOperatorName;
	/**
	 * 经办人用户名
	 */
	private String agrOperatorUsername;
	/**
	 * 排序
	 */
	private String orderBy;

}
